import { EditorBlock, EditorState, Modifier, SelectionState, } from 'draft-js';
import React, { Component } from 'react';
class CheckableListItem extends Component {
    constructor() {
        super(...arguments);
        this.onInputChange = () => {
            let { block, blockProps: { onToggle }, } = this.props;
            onToggle(block);
        };
        this.onMouseDown = (event) => {
            event.preventDefault();
        };
    }
    render() {
        let { offsetKey, block, blockProps: { readOnly }, } = this.props;
        let checked = !!block.getData().get('checked');
        return (React.createElement("div", { className: "checkable-list-item", "data-offset-key": offsetKey },
            React.createElement("div", { className: "checkable-list-item-checkbox", contentEditable: false },
                React.createElement("input", { type: "checkbox", checked: checked, disabled: readOnly, onChange: this.onInputChange, onMouseDown: this.onMouseDown })),
            React.createElement("div", { className: "checkable-list-item-content" },
                React.createElement(EditorBlock, Object.assign({}, this.props)))));
    }
}
export const checkableListItemRenderEntry = [
    'checkable-list-item',
    {
        element: 'li',
        wrapper: React.createElement("ul", { className: "public-DraftStyleDefault-ul checkable-list" }),
    },
];
export function createCheckableListItemEntry() {
    return [
        'checkable-list-item',
        ({ getEditorState, setEditorState, getReadOnly }) => {
            return {
                component: CheckableListItem,
                props: {
                    readOnly: getReadOnly(),
                    onToggle(block) {
                        let editorState = getEditorState();
                        let content = editorState.getCurrentContent();
                        let selection = editorState.getSelection();
                        let blockData = block.getData();
                        blockData = blockData.merge({
                            checked: !blockData.get('checked'),
                        });
                        let range = SelectionState.createEmpty(block.getKey());
                        content = Modifier.setBlockData(content, range, blockData).merge({
                            selectionAfter: selection,
                        });
                        setEditorState(EditorState.push(editorState, content, 'change-block-data'));
                    },
                },
            };
        },
    ];
}
//# sourceMappingURL=checkable-list-item.js.map