import { EditorBlock } from 'draft-js';
import React, { Component } from 'react';
import { CODE_BLOCK_COPIED_EVENT_NAME, CODE_BLOCK_COPY_ERROR_EVENT_NAME, } from '../constants';
const COPIED_TEXT_TIMEOUT = 1000;
class CodeBlock extends Component {
    constructor() {
        super(...arguments);
        this.state = { copied: false };
        this.onCopyButtonClick = (event) => {
            event.stopPropagation();
            this.copyContent();
        };
    }
    get content() {
        let { block } = this.props;
        return block.getText();
    }
    render() {
        let { offsetKey } = this.props;
        let { copied } = this.state;
        let classNames = ['code-block'];
        if (copied) {
            classNames.push('code-block-copied');
        }
        return (React.createElement("div", { className: classNames.join(' '), "data-offset-key": offsetKey },
            React.createElement(EditorBlock, Object.assign({}, this.props)),
            React.createElement("div", { className: "code-block-copy-button-wrapper", contentEditable: false },
                React.createElement("button", { className: "code-block-copy-button", disabled: copied, onClick: this.onCopyButtonClick }))));
    }
    copyContent() {
        navigator.clipboard
            .writeText(this.content)
            .then(() => {
            this.setCopied();
            this.dispatchCustomEvent(CODE_BLOCK_COPIED_EVENT_NAME);
        })
            .catch(() => this.dispatchCustomEvent(CODE_BLOCK_COPY_ERROR_EVENT_NAME));
    }
    setCopied() {
        this.setState({ ...this.state, copied: true });
        clearTimeout(this.copiedResetTimer);
        this.copiedResetTimer = setTimeout(() => {
            this.setState({ ...this.state, copied: false });
        }, COPIED_TEXT_TIMEOUT);
    }
    dispatchCustomEvent(name) {
        document.dispatchEvent(new CustomEvent(name));
    }
}
export function createCodeBlockEntry() {
    return [
        'code-block',
        () => {
            return {
                component: CodeBlock,
            };
        },
    ];
}
//# sourceMappingURL=code-block.js.map